<template>
    <div class="container">
      <h1 class="fs-3 fl-4">Credit Purchase for Road Image Analysis</h1>

      <p class="fl-5" v-html="contents ['subtext']"></p>

      <div class="fs-5 row fl-5 mt-10">
        <div class="row">
          <div class="col-sm-6 col-lg-4 fw-bold">Current Credit Balance</div>
          <div class="col-sm-6 col-lg-8">
            You currently have <span class="fw-bold">{{ creditBalance.format () }}</span> Credits
            <div class="reference">For {{ (creditBalance / 1000).format () }} km Road Analysis</div>
          </div>
        </div>
      </div>

      <transition name="slide">
        <form v-if='showForm' class="bg-grey-lighten-3 rounded-2 px-4 py-2 my-7 col-md-11 col-lg-9 col-xl-8 col-xxl-7">
          <div class="fs-5 row mt-4">
            <div class="col-sm-6 col-lg-5">
              Analysis Scope and Credit Selection
              <div class="reference">
                Maximum Credit Purchase Limit: {{ MAX_CREDITS.format () }} Credits.
              </div>
            </div>
            <div class="col-sm-6 col-lg-7">
              <div class="fs-6 mb-2 reference">Credit Packages for Purchase:</div>
              <bs-input name="options" v-model="state.credit.purchaising" placeholder="Select credits to purchase" :choices="amountOptions" type="radio"></bs-input>

              <div class="fs-6 mt-6 mb-2 reference">Alternatively, you may manually enter the desired number of credits.</div>
              <bs-input name="credits" v-model="state.credit.purchaising" class="type_credit" placeholder="Enter number of credits"></bs-input>
            </div>
          </div>
        </form>
      </transition>

      <div class="fs-5 row mt-4 fl-5">
        <div class="row">
          <div class="col-sm-6 col-lg-4 fw-bold">Selected Credit Package</div>
          <div class="col-sm-6 col-lg-8">
            <span class="fw-bold">{{ creditsToPurchaseAsInt.format () }}</span> Credits
            <div class="reference">
              This is suitable for {{ (creditsToPurchaseAsInt / 1000).format () }} km of road analysis</div>
            <div class="reference"> Expected Total Credits after Purchase: <b>{{ expectedCredits.format () }}</b></div>
          </div>
        </div>

        <div class="row">
          <div class="col-sm-6 col-lg-4 fw-bold">Pricing Details</div>
          <div class="col-sm-6 col-lg-8">
            Total credit cost: <span class="fw-bold">{{ state.credit.price_unit }} {{ creditPrice.format ('usd') }}</span>
            <div class="reference"> 1 Credit = <b>{{ state.credit.price_unit }} {{ state.credit.unit_price.toFixed (3) }}</b></div>
          </div>
        </div>

        <div class="row">
          <div class="col-sm-6 col-lg-4 fw-bold">Tax</div>
          <div class="col-sm-6 col-lg-8">
            <span class="fw-bold">{{ state.credit.price_unit }} {{ tax.format ('usd') }}</span>
          </div>
        </div>

        <div class="row mt-4">
          <div class="col-sm-6 col-lg-4 fw-bold">Total Amount</div>
          <div class="col-sm-6 col-lg-8">
            <span class="fw-bold">{{ state.credit.price_unit }} {{ amountTotal.format ('usd') }}</span>

          </div>
        </div>
      </div>


      <div class="col-md-11 col-lg-9 col-xl-8 col-xxl-7 border-top pt-3 mt-4 mb-16 actions">
        <div v-if="showForm">
          <button class="mr-4 btn btn-primary" type="button" @click="checkout">Proceed To Checkout</button>
          <button class="btn btn-secondary" type="button" @click="cancel">Cancel</button>
        </div>
        <button class="btn btn-secondary" type="button" @click="modifyOrder" v-else>Change Credit Quantity</button>
      </div>


      <transition name="fade">
        <form v-if='!showForm' class="paypal-actions bg-grey-lighten-3 rounded-2 p-1 px-4 my-16 col-md-11 col-lg-9 col-xl-8 col-xxl-7">
          <div class="row mt-4">
            <div class="col-sm-4 fs-5 mb-4">Checkout
              <div class="mt-2 fs-6 fw-bold">{{ state.credit.price_unit }} {{ amountTotal.format ('usd') }}</div>
              <div class="reference">for {{ creditsToPurchaseAsInt.format () }} Credits</div>
            </div>
            <div class="col-sm-8">
              <checkout-button @checkout="handleOrderResult"></checkout-button>
            </div>
          </div>
        </form>
      </transition>
    </div>
</template>





<style scoped>
.reference {
  color: #9f9f9f;
  font-size: 15px;
}
</style>

<style>
.type_credit input {
  width: 100px;
  text-align: right;
}
</style>




<script setup>
import BsInput from "/atila-vue/components/bs-input.vue"
import checkoutButton from "../components/checkout-button.vue"

const { state } = useStore ()
const router = useRouter ()

const MAX_CREDITS = 100000
state.credit.purchaising = state.credit.purchaising || 1000
const creditBalance = ref (0)
const showForm = ref (true)
const profile = ref ({})
const contents = ref ({})

const amountOptions = ref ([])
const _amountOptions = [1000, 5000, 10000, 50000, 100000]

for (let price of _amountOptions) {
  amountOptions.value.push ([price, `${price.format ()} Credits <span style="font-size: 14px; color: #888888;">for ${(price / 1000).format ()} km road analysis</span>`])
}

const creditsToPurchaseAsInt = computed (() => {
  return parseInt (state.credit.purchaising)
})

const expectedCredits = computed (() => {
  return creditBalance.value + parseInt (state.credit.purchaising)
})

const creditPrice = computed (() => {
  return parseInt (state.credit.purchaising) * state.credit.unit_price
})

const tax = computed (() => {
  if (profile.value.country == 'KR') return creditPrice.value * 0.1
  return 0.0
})

const amountTotal = computed (() => {
  return creditPrice.value + tax.value
})

async function checkout () {
  const validators = {credits: {required: true, type: 'int', between: [1000, MAX_CREDITS]}}
  if (frontend.validator.failed ({credits: state.credit.purchaising}, validators)) {
    return
  }
  frontend.gtag ('begin_checkout', {
    value: amountTotal,
    currency: state.credit.price_unit
  })
  showForm.value = false
}

async function modifyOrder () {
  showForm.value = true
  await frontend.sleep (500)
  document.querySelector ('#input-credits').focus ()
}

function cancel () {
  router.push ('/credit')
}

function handleOrderResult (orderData) {
  const transaction = orderData.purchase_units[0].payments.captures[0]
  if (transaction.status == 'COMPLETED') {
    frontend.gtag ('purchase', {
      value: transaction.amount.value,
      currency: transaction.amount.currency_code,
      transaction_id: transaction.id
    })
    bootstrap.toast ({title: "Success", text: "You have successfully purchased credits."})
    return router.push ('/credit')
  }
  bootstrap.modal ({
    title: 'Unable To Purchase Credits',
    text: `Transaction ${transaction.status}: ${transaction.id}. See console for all available details`,
    icon: "error",
    closeButtonText: 'Retry'
  })
}


onBeforeMount (async () => {
  contents.value = await frontend.fetch_contents ()

  let resp = null

  resp = await backend.get ('WEBCONTENTS_CONFIGS', {keys: 'CREDIT'})
  state.credit.unit_price = resp.data.CREDIT.digit_val
  state.credit.price_unit = resp.data.CREDIT.string_val

  resp = await backend.get ('CREDITS')
  creditBalance.value = resp.data.balance

  resp = await backend.get ('GET_PROFILES')
  profile.value = resp.data
})

onActivated (async () => {
  frontend.set_title ()
  showForm.value = true
})

</script>











<script>
export default {
  beforeRouteEnter (to, from, next) {
    frontend.permission.required (['user'], {path: '/members/signin'}, {to, from, next})
  }
}
</script>
